@@ -58,10 +58,10 @@ class hubspot:
     post_url = f"{self.base_url}oauth/v1/refresh-tokens/{self.refresh_token}"
     return Requests.delete(post_url, self.auth_headers)
 
-  def custom_request(self, method=None, endpoint=None, data=None):
+  def custom_request(self, method=None, endpoint=None, **kwargs):
     endpoint = endpoint.lstrip('/')
     post_url = f"{self.base_url}{endpoint}"
-    return getattr(Requests, method)(post_url, self.headers, data=data)
+    return getattr(Requests, method)(post_url, self.headers, **kwargs)
 
   def search_records_by_property_value(self, object_type, property_name, property_value, property_names=None, after=None, sorts=[]):
     filters = [
